# Firepup650
Package containing various shorthand things I use, and a few imports I almost always use
#### Change log:
###### v.1.0.23:
Adds `sql` (class) and all it's functions
###### v.1.0.22:
Adds `flush_print`.
###### v.1.0.21:
Adds `bad_cast_message` to `input` and `replit_input`.
###### v.1.0.20:
Fixes a bug where `replit_input` didn't cast to `cast`.
###### v.1.0.19:
Updates `replit_input` to call (new) custom `input` that supports type casting under the hood.
###### v.1.0.18:
Adds Ease Of Use stuff to `bcolors`.
###### v.1.0.17:
Adds `cprint`.
###### v.1.0.16:
Same as `v.1.0.15`. Should be fixed now.
###### v.1.0.15:
Same as `v.1.0.14`, but I can't use the same number
###### v.1.0.14:
Hopefully fixes poetry not showing certain project info.
###### v.1.0.13:
Adds `replit_input`
###### v.1.0.12:
Description fix for `gp`, add `gh`.
###### v.1.0.11:
Fix a bug in the `gp` method.
###### v.1.0.10:
Add the `REPLIT` color to `bcolors`, and add `replit_cursor` to the module.
###### v.1.0.9:
Small tweaks, nothing major.
###### v.1.0.8:
Can't install collections. This better fix it.
###### v.1.0.7:
Adds `console` (class), `bcolors` (class), and `Color` (function). Fixes type hinting on various things (Lots of thanks to [@bigminiboss](https://pypi.org/user/bigminiboss/)!).
###### v.1.0.6:
Hopefully, fixes an issue where the package doesn't install it's dependencies (Again. Hopefully.)
###### v.1.0.5:
Hopefully, fixes an issue where the package doesn't install it's dependencies
###### v.1.0.4:
Subscript errors
###### v.1.0.3:
Dependant errors
###### v.1.0.2:
Random shorthand (literally)
###### v.1.0.1:
Added animated typing function, sleep shorthand
###### v.1.0.0:
Initial Release!